pub struct BgzfChunkReader<R> { /* private fields */ }Expand description
A reader that decodes a sequence of virtual position ranges (“chunks”) in a BGZF-encoded file.
The chunks normally come from querying an index file with a genomic range.
Examples
use oxbow::util::query::BgzfChunkReader;
use std::fs::File;
use std::io::{self, BufReader};
use noodles::bgzf::VirtualPosition;
let inner = File::open("sample.bam").unwrap();
let bgzf_reader = noodles::bgzf::io::Reader::new(BufReader::new(inner));
let chunks = vec![
(VirtualPosition::from(0), VirtualPosition::from(6)),
(VirtualPosition::from(12), VirtualPosition::from(18)),
];
let mut chunk_reader = BgzfChunkReader::new(bgzf_reader, chunks);use oxbow::util::query::BgzfChunkReader;
use std::fs::File;
use std::io::{self, BufReader};
use noodles::core::region::Interval;
use noodles::csi::BinningIndex;
let inner = File::open("sample.bam").unwrap();
let index = noodles::bam::bai::fs::read("sample.bam.bai").unwrap();
let chrom_id = 4;
let interval = "101-200".parse::<Interval>().unwrap();
let bgzf_reader = noodles::bgzf::io::Reader::new(BufReader::new(inner));
let chunks: Vec<_> = index.query(chrom_id, interval).unwrap()
.into_iter().map(|c| (c.start(), c.end())).collect();
let mut chunk_reader = BgzfChunkReader::new(bgzf_reader, chunks);Implementations
Sourceimpl<R> BgzfChunkReader<R>
impl<R> BgzfChunkReader<R>
pub fn new(reader: R, chunks: Vec<VirtualRange>) -> Self