pub struct SampleStructBuilder { /* private fields */ }Expand description
A single-sample genotype data builder.
Builds a StructArray, one variant per row, of a single sample’s genotype data, covering a defined list of genotype fields.
Implementations
Sourceimpl SampleStructBuilder
impl SampleStructBuilder
pub fn new(genotype_defs: Vec<GenotypeDef>) -> Self
pub fn get_arrow_fields(&self) -> Vec<ArrowField>
pub fn push( &mut self, sample_data: IndexMap<String, Option<Value<'_>>>, ) -> Result<()>
pub fn finish(&mut self) -> StructArray