pub struct Scanner { /* private fields */ }Expand description
A BAM scanner.
Schema parameters (fields, tag definitions) are declared at construction time. Scan methods accept only column projection, batch size, and limit.
Examples
use oxbow::alignment::scanner::bam::Scanner;
use oxbow::Select;
use std::fs::File;
use std::io::BufReader;
let inner = File::open("sample.bam").map(BufReader::new).unwrap();
let mut fmt_reader = noodles::bam::io::Reader::new(inner);
let header = fmt_reader.read_header().unwrap();
let tag_defs = Scanner::tag_defs(&mut fmt_reader, Some(1000)).unwrap();
let scanner = Scanner::new(header, Select::All, Some(tag_defs)).unwrap();
let batches = scanner.scan(fmt_reader, None, None, Some(1000));Implementations
Sourceimpl Scanner
impl Scanner
Sourcepub fn new(
header: Header,
fields: Select<String>,
tag_defs: Option<Vec<(String, String)>>,
) -> Result<Self>
pub fn new( header: Header, fields: Select<String>, tag_defs: Option<Vec<(String, String)>>, ) -> Result<Self>
Creates a BAM scanner from a SAM header and schema parameters.
fields: standard SAM field selection.tag_defs:None→ no tags column.Some(vec![])→ empty struct.
Sourcepub fn with_model(header: Header, model: AlignmentModel) -> Self
pub fn with_model(header: Header, model: AlignmentModel) -> Self
Creates a BAM scanner from an AlignmentModel.
Sourcepub fn model(&self) -> &AlignmentModel
pub fn model(&self) -> &AlignmentModel
Returns a reference to the AlignmentModel.
Sourcepub fn chrom_names(&self) -> Vec<String>
pub fn chrom_names(&self) -> Vec<String>
Returns the reference sequence names.
Sourcepub fn chrom_sizes(&self) -> Vec<(String, u32)>
pub fn chrom_sizes(&self) -> Vec<(String, u32)>
Returns the reference sequence names and lengths.
Sourcepub fn field_names(&self) -> Vec<String>
pub fn field_names(&self) -> Vec<String>
Returns the field names declared in the model.
Sourceimpl Scanner
impl Scanner
Sourcepub fn tag_defs<R: Read>(
fmt_reader: &mut Reader<R>,
scan_rows: Option<usize>,
) -> Result<Vec<(String, String)>>
pub fn tag_defs<R: Read>( fmt_reader: &mut Reader<R>, scan_rows: Option<usize>, ) -> Result<Vec<(String, String)>>
Discovers tag definitions by scanning over records.
The scan will begin at the current position of the reader and will move the cursor to the end of the last record scanned.
Sourcepub fn scan<R: Read>(
&self,
fmt_reader: Reader<R>,
columns: Option<Vec<String>>,
batch_size: Option<usize>,
limit: Option<usize>,
) -> Result<impl RecordBatchReader>
pub fn scan<R: Read>( &self, fmt_reader: Reader<R>, columns: Option<Vec<String>>, batch_size: Option<usize>, limit: Option<usize>, ) -> Result<impl RecordBatchReader>
Returns an iterator yielding record batches.
The scan will begin at the current position of the reader and will move the cursor to the end of the last record scanned.
Sourcepub fn scan_query<R: BufRead + Seek>(
&self,
fmt_reader: Reader<R>,
region: Region,
index: impl BinningIndex,
columns: Option<Vec<String>>,
batch_size: Option<usize>,
limit: Option<usize>,
) -> Result<impl RecordBatchReader>
pub fn scan_query<R: BufRead + Seek>( &self, fmt_reader: Reader<R>, region: Region, index: impl BinningIndex, columns: Option<Vec<String>>, batch_size: Option<usize>, limit: Option<usize>, ) -> Result<impl RecordBatchReader>
Returns an iterator yielding record batches satisfying a genomic range query.
This operation requires a BGZF source and an Index.
The scan will traverse one or more virtual position ranges and filter for records that overlap the given region. The cursor will stop at the end of the last record scanned.
Sourcepub fn scan_unmapped<R: BufRead + Seek>(
&self,
fmt_reader: Reader<R>,
index: impl BinningIndex,
columns: Option<Vec<String>>,
batch_size: Option<usize>,
limit: Option<usize>,
) -> Result<impl RecordBatchReader>
pub fn scan_unmapped<R: BufRead + Seek>( &self, fmt_reader: Reader<R>, index: impl BinningIndex, columns: Option<Vec<String>>, batch_size: Option<usize>, limit: Option<usize>, ) -> Result<impl RecordBatchReader>
Returns an iterator yielding record batches of unaligned reads.
This operation requires a BGZF source and an Index.
The scan will start at the offset where unmapped reads begin and continue until the source stream is exhausted.
Sourcepub fn scan_byte_ranges<R: BufRead + Seek>(
&self,
fmt_reader: Reader<R>,
byte_ranges: Vec<(u64, u64)>,
columns: Option<Vec<String>>,
batch_size: Option<usize>,
limit: Option<usize>,
) -> Result<impl RecordBatchReader>
pub fn scan_byte_ranges<R: BufRead + Seek>( &self, fmt_reader: Reader<R>, byte_ranges: Vec<(u64, u64)>, columns: Option<Vec<String>>, batch_size: Option<usize>, limit: Option<usize>, ) -> Result<impl RecordBatchReader>
Returns an iterator yielding record batches from specified byte ranges.
This operation requires a seekable (typically uncompressed) source.
The scan will traverse the specified byte ranges without filtering by genomic coordinates. This is useful when you have pre-computed file offsets from a custom index. The byte ranges must align with record boundaries.
Sourcepub fn scan_virtual_ranges<R: BufRead + Seek>(
&self,
fmt_reader: Reader<R>,
vpos_ranges: Vec<(VirtualPosition, VirtualPosition)>,
columns: Option<Vec<String>>,
batch_size: Option<usize>,
limit: Option<usize>,
) -> Result<impl RecordBatchReader>
pub fn scan_virtual_ranges<R: BufRead + Seek>( &self, fmt_reader: Reader<R>, vpos_ranges: Vec<(VirtualPosition, VirtualPosition)>, columns: Option<Vec<String>>, batch_size: Option<usize>, limit: Option<usize>, ) -> Result<impl RecordBatchReader>
Returns an iterator yielding record batches from specified virtual position ranges.
This operation requires a BGZF-compressed source.
The scan will traverse the specified virtual position ranges without filtering by genomic coordinates. This is useful when you have pre-computed virtual offsets from a custom index.